/* libiir/src/libiir/500_response.h
 * 
 *  Copyright: ©2011, Laurence Withers.
 *  Author: Laurence Withers <l@lwithers.me.uk>
 *  License: GPLv3
*/



/*! \defgroup response Measuring IIR response

These functions allow measuring the IIR response (i.e. frequency and phase of
the transfer function) at a given frequency. The response is a complex number;
see \c complex(5) for details. The magnitude \c cabs(z) is the gain of the
filter and the phase \c carg(z) its phase delay.

*/
/*!@{*/



/*! \brief Find response of coefficients at a single frequency.

\param coeff Set of coefficients.
\param freq Frequency of interest, as a fraction of sample rate.
\returns Response as complex number.

*/
double complex iir_response_c(const struct iir_coeff_t* coeff, double freq);



/*! \brief Find response of filter at a single frequency.

\param fi Filter to evaluate.
\param freq Frequency of interest, as a fraction of sample rate.
\returns Response as a complex number.

Similar to \ref iir_response_c(), except that it works on an instantiated
filter (and takes all parts of a chained filter into account). Does not alter
the state of the filter in any way and calls may be interleaved with filter
evaluation.

*/
double complex iir_response(const struct iir_filter_t* fi, double freq);



/*!@}*/
/* options for text editors
vim: expandtab:ts=4:sw=4:syntax=c.doxygen
*/
